---
title: Welcome to mkdocs-shadcn
summary: Beautifully designed mkdocs theme
sidebar_title: Home
order: 0
---


First and foremost, this is an unofficial port of [shadcn/ui](https://ui.shadcn.com/) to [MkDocs](https://www.mkdocs.org), and is not affiliated with [@shadcn](https://twitter.com/shadcn).

The main goal of this project is to port the shadcn style to mkdocs while avoiding to turn it into a whole framework of the death.

So first it should support [built-in extensions](https://python-markdown.github.io/extensions/) and some [`pymdownx`](https://facelessuser.github.io/pymdown-extensions/) ones.

